Learn R Programming

ungeneanno (version 0.1.6)

getGeneSummary: Create gene specific objects containing data from online resources

Description

getGeneSummary populates and returns a vector of gene objects with information sourced from a series of html requests to the NIH and Uniport publicly available databases.

Usage

getGeneSummary(x)
"getGeneSummary"(x)

Arguments

x
object of class geneanno.

Value

vector of gene objects, each containing the collated data from the public resources.

Methods (by class)

  • geneanno: Produces a vector of gene objects, each containing the collated data from the public resources.

Details

Information returned from a database requests is parsed into a gene object, which are saved in a 'genes' subdirectory of the working directory. Each gene object is added to a vector of objects, which is then returned. Where gene information has previously been downloaded and objects saved (within the last seven days), gene objects are repopulated from the saved files so as to minimise server traffic. N.B. the function includes a random wait (of up to 5s) between each gene downloaded.

N.B. It is possible to define an alternative directory using geneanno@fileroot <- "/path/to/directory"

Examples

Run this code
## Not run: 
# geneanno@fileroot <- "~/Desktop"
# genesummaries <- getGeneSummary(geneanno)
# ## End(Not run)

Run the code above in your browser using DataLab