Learn R Programming

ungeneanno (version 0.1.6)

getGroupGeneList: Create unique list of group,gene combinations from input list

Description

getGroupGeneList takes a mixed list of group identifiers (numeric) and gene names or a 2-column matrix of group identifiers and gene names, returning the seperated list of group identifiers and the related lists of genes.

Usage

getGroupGeneList(x, inputlist)
"getGroupGeneList"(x, inputlist)
"getGroupGeneList"(x, inputlist)

Arguments

x
object of class geneanno.
inputlist
vector of strings, being a mixed list of group numbers and gene names

Value

object of type geneanno; a copy of input object having the additional list of group numbers and a unique list of genes from s

Methods (by class)

  • x = geneanno,inputlist = character: uses vector of characters of group ids and Gene names for inputlist.
  • x = geneanno,inputlist = matrix: uses matrix of group ids and Gene names for inputlist.

Examples

Run this code
## Not run: 
# data("genematrix")
# dgl <- getGroupGeneList(geneanno(),genematrix)
# ## End(Not run)

Run the code above in your browser using DataLab