Learn R Programming

ungeneanno (version 0.1.6)

getPublicationList: Gather NIH Pubmed Data

Description

getPublicationList collates Pubmed data returned from a html request for input string.

Usage

getPublicationList(query)
"getPublicationList"(query)

Arguments

query
A query string to be submitted to Pubmed

Value

A vector of pubmed objects each detailing a publication relating to the entered query combination requested.

Methods (by class)

  • character: as above.

Examples

Run this code
## Not run: 
# query <- "Thompson IR HIV"
# ReturnedPublications <- getPublicationList(query)
# ## End(Not run)

Run the code above in your browser using DataLab