Learn R Programming

ungeneanno (version 0.1.6)

getUniprotSummary: Gather Uniprot Data

Description

getUniprotSummary collates data returned from a html request to the Uniport publicly available databases to populate the gene object. The query currently returns id, entry name, reviewed, protein names, genes, organism, length and "comment(FUNCTION)".

Usage

getUniprotSummary(x, y)
"getUniprotSummary"(x, y)

Arguments

x
gene object
y
query object (see getNihQuery())

Value

gene object - a copy of the input object 'y', having the uniprot data added.

Methods (by class)

  • gene: gene object - a copy of the input object 'y', having the uniprot data added.

See Also

http://www.uniprot.org/help/uniprotkb_column_names

Examples

Run this code
## Not run: 
# f <- query()
# f@gene <- "BRAF"
# gene <- gene()
# gene@name <- f@gene
# gene <- getUniprotSummary(gene,f)
# ## End(Not run)

Run the code above in your browser using DataLab