Learn R Programming

ungeneanno (version 0.1.6)

getUniqueGeneList: Create unique list of genes from input list

Description

getUniqueGeneList takes a 2-column matrix of group identifiers and gene names, returning the seperated list of unique group identifiers and a unique list of genes.

Usage

getUniqueGeneList(x, inputlist)
"getUniqueGeneList"(x, inputlist)
"getUniqueGeneList"(x, inputlist)

Arguments

x
object of class geneanno.
inputlist
vector of strings, being a mixed list of group numbers and gene names

Value

object of type geneanno; a copy of input object having the additional list of group numbers and a list of genes from uniquelist

Methods (by class)

  • x = geneanno,inputlist = character: object of type geneanno; a copy of input object having the additional list of group numbers and a unique list of genes from s
  • x = geneanno,inputlist = matrix: object of type geneanno; a copy of input object having the additional list of group numbers and a unique list of genes from s

Examples

Run this code
## Not run: 
# data("genematrix")
# ga <- getUniqueGeneList(ga,genematrix)
# ## End(Not run)

Run the code above in your browser using DataLab