Learn R Programming

ungeneanno (version 0.1.6)

produceOutputFiles: Save Gene Information to group Specific Output Files

Description

produceOutputFiles saves the downloaded gene summary information into group specific files.

Usage

produceOutputFiles(x, dgl, gs, pub)
"produceOutputFiles"(x, dgl, gs)
"produceOutputFiles"(x, dgl, gs, pub)

Arguments

x
object of class geneanno.
dgl
a Vector of group specific vectors relating the list of genes to the groups, as in the input file
gs
Vector of Gene Summary information downloaded from NIH and Uniprot databases, typically output by getGeneSummary
pub
Matrix containing journal article information from the PubMed resource, as retruned by the searchPublications function

Methods (by class)

  • x = geneanno,dgl = vector,gs = vector,pub = missing: Save object data to text files.
  • x = geneanno,dgl = vector,gs = vector,pub = vector: Save object data, including journal articles, to text files.