genematrix: Input Matrix of Drug/Gene Data
Description
A matrix made up of a column of drug identifiers and a column of associated gene names, as used for input into getUniqueGeneList() and
Format
A 2 column matrix where the first columns contains drug identifiers and the second column Gene names.