getNihSummary collates data returned from a html request to the NCBI publicly available gene database to populate the gene object.
Accessing the NCBI NIH databases is a two stage process; the getNihSummary function
carries out the second stage in relation to the NCBI "gene" database, populating NIH specific slots in a gene object.
Usage
getNihSummary(x, y)
"getNihSummary"(x, y)
Arguments
x
gene object
y
query object (see getNihQuery())
Value
gene object a copy of the input object 'x', having the uniprot data added.
Methods (by class)
gene: gene object a copy of the input object 'x', having the uniprot data added.