getUniprotSummary collates data returned from a html request to the Uniport publicly available databases to populate the gene object.
The query currently returns id, entry name, reviewed, protein names, genes, organism, length and "comment(FUNCTION)".
Usage
getUniprotSummary(x, y)
"getUniprotSummary"(x, y)
Arguments
x
gene object
y
query object (see getNihQuery())
Value
gene object - a copy of the input object 'y', having the uniprot data added.
Methods (by class)
gene: gene object - a copy of the input object 'y', having the uniprot data added.