searchPublications: Carry out Pubmed search for a mtrix
Description
searchPublications carries out a series of Pubmed searches for each row of information in the given matrix.
The function uses the same matrix used for input to the getUniqueGeneList function, however
given the nature of the search it is best to ensure the groups have meaningful names and not arbitrary numbers.
Usage
searchPublications(query)
"searchPublications"(query)
Arguments
query
A matrix, as input to getUniqueGenes, string to be submitted to Pubmed
Value
A 2 column matrix containg the query string and a list of pubmed objects each detailing a publication relating to the respective query.