## Not run:
# ## Create geneanno object and set save directory
# ga <- geneanno()
# ga@fileroot <- "~/Desktop"
#
# ## Parse input gene names and group identifiers into unique lists
# data("genematrix")
# ga <- getUniqueGeneList(ga,genematrix)
#
# ## Query databases and Parse responses
# gs <- getGeneSummary(ga)
#
# ## Create vector of vectors containing gene names for each group identifier
# dgl <- getGroupGeneList(ga,genematrix)
#
# ## Collate data into out files
# produceOutputFiles(ga, dgl, gs)
#
# ## Query PubMed database
# query <- "Thompson IR HIV"
# ReturnedPublications <- getPublicationList(query)
#
# ## List PubMedIDs from PubMed query
# for (i in 1:length(ReturnedPublications)){
# print(ReturnedPublications[[i]]@Id)
# }
# ## End(Not run)
Run the code above in your browser using DataLab